==> haskell-implicit-hie-0.1.4.0-48-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie
version:              0.1.4.0
visibility:           public
id:                   implicit-hie-0.1.4.0-4gORIw4Q5qr9jIMIe76RUm
key:                  implicit-hie-0.1.4.0-4gORIw4Q5qr9jIMIe76RUm
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  da9f0c04ed85306332a7502eccf4ce8d
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.4.0-4gORIw4Q5qr9jIMIe76RUm
depends:
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    filepattern-0.1.3-FK99gLf9GZp3R2i6OiwyKP text-2.0.2
    transformers-0.5.6.2 yaml-0.11.11.2-AOYlSEsKg9dHqSBpc42qFm

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-implicit-hie-0.1.4.0-67-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie
version:              0.1.4.0
visibility:           public
id:                   implicit-hie-0.1.4.0-1PjgBq5GgmFHElPc0sqYLl
key:                  implicit-hie-0.1.4.0-1PjgBq5GgmFHElPc0sqYLl
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  0708061b053585944ebbb21a63d1939e
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.4.0-1PjgBq5GgmFHElPc0sqYLl
depends:
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    filepattern-0.1.3-AGW6edTqaTDDecTKGYlwIU text-2.0.2
    transformers-0.5.6.2 yaml-0.11.11.2-AINh0PDgMr7KUeC4aAoheB

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
